# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`sssd`](#sssd): This class allows you to install and configure SSSD.  It will forcefully disable nscd which consequently prevents you from using an nscd modu
* [`sssd::config`](#sssdconfig): Configuration class called from sssd.  Sets up the ``[sssd]`` section of '/etc/sssd/sssd.conf', and, optionally, a domain section for the IPA
* [`sssd::config::ipa_domain`](#sssdconfigipa_domain): Configures SSSD for the IPA domain to which the host has joined
* [`sssd::install`](#sssdinstall): Install the required packages for SSSD
* [`sssd::install::client`](#sssdinstallclient): Install the sssd-client package
* [`sssd::pki`](#sssdpki): Class: sssd::pki  Uses the following sssd class parameters to copy certs into a directory for the sssd application  $sssd::pki   * If 'simp',
* [`sssd::service`](#sssdservice): Control the `sssd` service
* [`sssd::service::autofs`](#sssdserviceautofs): This class sets up the [autofs] section of /etc/sssd.conf.  The class parameters map directly to SSSD configuration.  Full documentation of t
* [`sssd::service::ifp`](#sssdserviceifp): This class sets up the [ifp] section of /etc/sssd.conf.  The class parameters map directly to SSSD configuration.  Full documentation of thes
* [`sssd::service::nss`](#sssdservicenss): This class sets up the [nss] section of /etc/sssd.conf. You may only have one of these per system.  The class parameters map directly to SSSD
* [`sssd::service::pac`](#sssdservicepac): This class sets up the [pac] section of /etc/sssd.conf.  The class parameters map directly to SSSD configuration.  Full documentation of thes
* [`sssd::service::pam`](#sssdservicepam)
* [`sssd::service::ssh`](#sssdservicessh): This class sets up the [ssh] section of /etc/sssd.conf.  The class parameters map directly to SSSD configuration.  Full documentation of thes
* [`sssd::service::sudo`](#sssdservicesudo): This class sets up the [sudo] section of /etc/sssd.conf.  The class parameters map directly to SSSD configuration.  Full documentation of the

### Defined types

* [`sssd::config::entry`](#sssdconfigentry): Add an entry to the /etc/sssd/conf.d directory
* [`sssd::domain`](#sssddomain): Define: sssd::domain  This define sets up a domain section of /etc/sssd.conf. This domain will be named after '$name' and should be listed in
* [`sssd::provider::ad`](#sssdproviderad): Set up the 'ad' (Active Directory) id_provider section of a particular domain.
* [`sssd::provider::files`](#sssdproviderfiles): Configures the 'files' id_provider section of a particular domain.
* [`sssd::provider::ipa`](#sssdprovideripa): This define sets up the 'ipa' provider section of a particular domain. $name should be the name of the associated domain in sssd.conf.  See s
* [`sssd::provider::krb5`](#sssdproviderkrb5): Define: sssd::provider::krb5  This define sets up the 'krb5' provider section of a particular domain. $name should be the name of the associa
* [`sssd::provider::ldap`](#sssdproviderldap): Define: sssd::provider::ldap  This define sets up the 'ldap' provider section of a particular domain. $name should be the name of the associa

### Functions

* [`sssd::supported_version`](#sssdsupported_version): Returns ``true`` if the version of SSSD installed on the system is supported and ``false`` otherwise.  Assumes that the system is relatively 

### Data types

* [`Sssd::ADDefaultRight`](#sssdaddefaultright): List of valid types for AD Provider setting ad_gpo_default_right
* [`Sssd::AccessProvider`](#sssdaccessprovider): List of valid  SSSD domain access providers
* [`Sssd::AuthProvider`](#sssdauthprovider): List of valid types for sssd domain authentication provider
* [`Sssd::ChpassProvider`](#sssdchpassprovider): List of valid types for sssd domain change password provider
* [`Sssd::DebugLevel`](#sssddebuglevel): Integer[0-9] or 2 byte Hexidecimal (ex. 0x0201)
* [`Sssd::IdProvider`](#sssdidprovider): List of valid type for sssd domain ID provider.
* [`Sssd::LdapAccessOrder`](#sssdldapaccessorder): List of valid values for ldap provider ldap_access_order setting
* [`Sssd::LdapAccountExpirePol`](#sssdldapaccountexpirepol): List of valid values for ldap provider ldap_account_expire_policy '' corresponds to the default value (empty) per sssd-ldap(5) man page
* [`Sssd::LdapDefaultAuthtok`](#sssdldapdefaultauthtok): List of valid values for ldap provider default auth token
* [`Sssd::LdapDeref`](#sssdldapderef): List of valid values for ldap provider deref setting
* [`Sssd::LdapSchema`](#sssdldapschema): List of valid setting for ldap provider ldap_schema setting.
* [`Sssd::LdapTlsReqcert`](#sssdldaptlsreqcert): List of valid setting for ldap provider ldap_tls_reqcert.
* [`Sssd::Services`](#sssdservices): List of available sssd services

## Classes

### <a name="sssd"></a>`sssd`

This class allows you to install and configure SSSD.

It will forcefully disable nscd which consequently prevents you from
using an nscd module at the same time, which is the correct behavior.

Full documentation of the parameters that map directly to SSSD
configuration options can be found in the sssd.conf(5) man page.

#### Parameters

The following parameters are available in the `sssd` class:

* [`authoritative`](#authoritative)
* [`domains`](#domains)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`description`](#description)
* [`enable_files_domain`](#enable_files_domain)
* [`config_file_version`](#config_file_version)
* [`services`](#services)
* [`reconnection_retries`](#reconnection_retries)
* [`re_expression`](#re_expression)
* [`full_name_format`](#full_name_format)
* [`try_inotify`](#try_inotify)
* [`krb5_rcache_dir`](#krb5_rcache_dir)
* [`user`](#user)
* [`default_domain_suffix`](#default_domain_suffix)
* [`override_space`](#override_space)
* [`enumerate_users`](#enumerate_users)
* [`include_svc_config`](#include_svc_config)
* [`cache_credentials`](#cache_credentials)
* [`min_id`](#min_id)
* [`auditd`](#auditd)
* [`pki`](#pki)
* [`app_pki_cert_source`](#app_pki_cert_source)
* [`app_pki_dir`](#app_pki_dir)
* [`auto_add_ipa_domain`](#auto_add_ipa_domain)
* [`custom_config`](#custom_config)

##### <a name="authoritative"></a>`authoritative`

Data type: `Boolean`

Whether or not to purge all unmanaged files from /etc/sssd/conf.d.

Default value: ``false``

##### <a name="domains"></a>`domains`

Data type: `Array[String[1, 255]]`

The sssd `domains` to be managed.

Default value: `[]`

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::DebugLevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Boolean`



Default value: ``true``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="description"></a>`description`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="enable_files_domain"></a>`enable_files_domain`

Data type: `Boolean`



Default value: ``true``

##### <a name="config_file_version"></a>`config_file_version`

Data type: `Integer[1]`



Default value: `2`

##### <a name="services"></a>`services`

Data type: `Sssd::Services`



Default value: `['nss','pam','ssh','sudo']`

##### <a name="reconnection_retries"></a>`reconnection_retries`

Data type: `Integer[0]`



Default value: `3`

##### <a name="re_expression"></a>`re_expression`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="full_name_format"></a>`full_name_format`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="try_inotify"></a>`try_inotify`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="krb5_rcache_dir"></a>`krb5_rcache_dir`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="user"></a>`user`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="default_domain_suffix"></a>`default_domain_suffix`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="override_space"></a>`override_space`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="enumerate_users"></a>`enumerate_users`

Data type: `Boolean`

Have SSSD list and cache all the users that it can find on the remote system

* Take care that you don't overwhelm your server if you enable this

Default value: ``false``

##### <a name="include_svc_config"></a>`include_svc_config`

Data type: `Boolean`

If set to true, config will loop through the services set in
sssd:service and include the configuration section for it.
At this time the service sections contain only the most common
parameters used. If you need to set a param that is not included you
can turn this off and create a custom manifest to add the section
you need.  If you simply want to change a setting that exists, use hiera.

Default value: ``true``

##### <a name="cache_credentials"></a>`cache_credentials`

Data type: `Boolean`

Have SSSD cache the credentials of users that login to the system

Default value: ``true``

##### <a name="min_id"></a>`min_id`

Data type: `Integer[0]`

The lowest user ID that SSSD should recognize from the server.

Default value: `1`

##### <a name="auditd"></a>`auditd`

Data type: `Boolean`



Default value: `simplib::lookup('simp_options::auditd', { 'default_value' => false})`

##### <a name="pki"></a>`pki`

Data type: `Variant[Boolean,Enum['simp']]`

* If 'simp', include SIMP's pki module and use pki::copy to manage
  application certs in /etc/pki/simp_apps/sssd/x509
* If true, do *not* include SIMP's pki module, but still use pki::copy
  to manage certs in /etc/pki/simp_apps/sssd/x509
* If false, do not include SIMP's pki module and do not use pki::copy
  to manage certs.  You will need to appropriately assign a subset of:
  * app_pki_dir
  * app_pki_key
  * app_pki_cert
  * app_pki_ca
  * app_pki_ca_dir

Default value: `simplib::lookup('simp_options::pki', { 'default_value' => false})`

##### <a name="app_pki_cert_source"></a>`app_pki_cert_source`

Data type: `Stdlib::Absolutepath`

* If pki = 'simp' or true, this is the directory from which certs will be
  copied, via pki::copy.  Defaults to /etc/pki/simp/x509.

* If pki = false, this variable has no effect.

Default value: `simplib::lookup('simp_options::pki::source', { 'default_value' => '/etc/pki/simp/x509'})`

##### <a name="app_pki_dir"></a>`app_pki_dir`

Data type: `Stdlib::Absolutepath`

This variable controls the basepath of $app_pki_key, $app_pki_cert,
$app_pki_ca, $app_pki_ca_dir, and $app_pki_crl.
It defaults to /etc/pki/simp_apps/sssd/x509.

Default value: `'/etc/pki/simp_apps/sssd/x509'`

##### <a name="auto_add_ipa_domain"></a>`auto_add_ipa_domain`

Data type: `Boolean`

Whether to configure sssd for an IPA domain, when the host is joined
to an IPA domain. When enabled, this feature helps to prevent user
lockout for IPA-managed user accounts.  Otherwise, you must
configure the IPA domain yourself.

Default value: ``true``

##### <a name="custom_config"></a>`custom_config`

Data type: `Optional[String[1]]`

A configuration that will be added to
/etc/sssd/conf.d/00_puppet_custom.conf *without validation*

Default value: ``undef``

### <a name="sssdconfig"></a>`sssd::config`

Configuration class called from sssd.

Sets up the ``[sssd]`` section of '/etc/sssd/sssd.conf', and,
optionally, a domain section for the IPA domain to which the host
is joined.  When the IPA domain is configured, the IPA domain is
automatically added to ``$domains`` to generate the list of domains
in the ``[sssd]`` section.

#### Parameters

The following parameters are available in the `sssd::config` class:

* [`authoritative`](#authoritative)

##### <a name="authoritative"></a>`authoritative`

Data type: `Boolean`

Set to `true` to purge unmanaged configuration files

Default value: `pick(getvar("${module_name}::authoritative"), false)`

### <a name="sssdconfigipa_domain"></a>`sssd::config::ipa_domain`

Configures SSSD for the IPA domain to which the host has joined

### <a name="sssdinstall"></a>`sssd::install`

Install the required packages for SSSD

#### Parameters

The following parameters are available in the `sssd::install` class:

* [`install_user_tools`](#install_user_tools)
* [`package_ensure`](#package_ensure)

##### <a name="install_user_tools"></a>`install_user_tools`

Data type: `Boolean`

If ``true``, install the 'sssd-tools' package for administrative
changes to the SSSD databases

Default value: ``true``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

Ensure setting for all packages installed by this module

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="sssdinstallclient"></a>`sssd::install::client`

Install the sssd-client package

#### Parameters

The following parameters are available in the `sssd::install::client` class:

* [`ensure`](#ensure)

##### <a name="ensure"></a>`ensure`

Data type: `Any`

Ensure setting for 'sssd-client' package

Default value: `$::sssd::install::package_ensure`

### <a name="sssdpki"></a>`sssd::pki`

Class: sssd::pki

Uses the following sssd class parameters to copy certs into
a directory for the sssd application

$sssd::pki
  * If 'simp', include SIMP's pki module and use pki::copy to manage
    application certs in /etc/pki/simp_apps/sssd/x509
  * If true, do *not* include SIMP's pki module, but still use pki::copy
    to manage certs in /etc/pki/simp_apps/sssd/x509
  * If false, do not include SIMP's pki module and do not use pki::copy
    to manage certs.  You will need to appropriately assign a subset of:
    * app_pki_dir
    * app_pki_key
    * app_pki_cert
    * app_pki_ca
    * app_pki_ca_dir

$ssd::app_pki_cert_source
  * If $sssd::pki = 'simp' or true, this is the directory from which certs will be
    copied, via pki::copy.  Defaults to /etc/pki/simp/x509.

  * If $sssd::pki = false, this variable has no effect.

### <a name="sssdservice"></a>`sssd::service`

Control the `sssd` service

#### Parameters

The following parameters are available in the `sssd::service` class:

* [`ensure`](#ensure)
* [`enable`](#enable)

##### <a name="ensure"></a>`ensure`

Data type: `Variant[String[1],Boolean]`

The `ensure` parameter of the service resource

Default value: `sssd::supported_version()`

##### <a name="enable"></a>`enable`

Data type: `Boolean`

The `enable` parameter of the service resource

Default value: `sssd::supported_version()`

### <a name="sssdserviceautofs"></a>`sssd::service::autofs`

This class sets up the [autofs] section of /etc/sssd.conf.

The class parameters map directly to SSSD configuration.  Full
documentation of these configuration options can be found in the
sssd.conf(5) man page.

#### Parameters

The following parameters are available in the `sssd::service::autofs` class:

* [`description`](#description)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`autofs_negative_timeout`](#autofs_negative_timeout)
* [`custom_options`](#custom_options)

##### <a name="description"></a>`description`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::DebugLevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Boolean`



Default value: ``true``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="autofs_negative_timeout"></a>`autofs_negative_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="custom_options"></a>`custom_options`

Data type: `Optional[Hash]`

If defined, this hash will be used to create the service
section instead of the parameters.  You must provide all options
in the section you want to add.  Each entry in the hash will be
added as a simple init pair key = value under the section in
the sssd.conf file.
No error checking will be performed.

Default value: ``undef``

### <a name="sssdserviceifp"></a>`sssd::service::ifp`

This class sets up the [ifp] section of /etc/sssd.conf.

The class parameters map directly to SSSD configuration.  Full
documentation of these configuration options can be found in the
sssd.conf(5) and sssd-ifp man pages.

#### Parameters

The following parameters are available in the `sssd::service::ifp` class:

* [`description`](#description)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`wildcard_limit`](#wildcard_limit)
* [`allowed_uids`](#allowed_uids)
* [`user_attributes`](#user_attributes)
* [`custom_options`](#custom_options)

##### <a name="description"></a>`description`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::Debuglevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Boolean`



Default value: ``true``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="wildcard_limit"></a>`wildcard_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="allowed_uids"></a>`allowed_uids`

Data type: `Optional[Array[String[1]]]`



Default value: ``undef``

##### <a name="user_attributes"></a>`user_attributes`

Data type: `Optional[Array[String[1]]]`



Default value: ``undef``

##### <a name="custom_options"></a>`custom_options`

Data type: `Optional[Hash]`

If defined, this hash will be used to create the service
section instead of the parameters.  You must provide all options
in the section you want to add.  Each entry in the hash will be
added as a simple init pair
 key = value
under the section in the sssd.conf file.
No error checking will be performed.

Default value: ``undef``

### <a name="sssdservicenss"></a>`sssd::service::nss`

This class sets up the [nss] section of /etc/sssd.conf.
You may only have one of these per system.

The class parameters map directly to SSSD configuration.  Full
documentation of these configuration options can be found in the
sssd.conf(5) man page.

#### Parameters

The following parameters are available in the `sssd::service::nss` class:

* [`description`](#description)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`reconnection_retries`](#reconnection_retries)
* [`fd_limit`](#fd_limit)
* [`command`](#command)
* [`enum_cache_timeout`](#enum_cache_timeout)
* [`entry_cache_nowait_percentage`](#entry_cache_nowait_percentage)
* [`entry_negative_timeout`](#entry_negative_timeout)
* [`filter_users`](#filter_users)
* [`filter_groups`](#filter_groups)
* [`filter_users_in_groups`](#filter_users_in_groups)
* [`override_homedir`](#override_homedir)
* [`fallback_homedir`](#fallback_homedir)
* [`override_shell`](#override_shell)
* [`vetoed_shells`](#vetoed_shells)
* [`default_shell`](#default_shell)
* [`get_domains_timeout`](#get_domains_timeout)
* [`memcache_timeout`](#memcache_timeout)
* [`user_attributes`](#user_attributes)
* [`custom_options`](#custom_options)

##### <a name="description"></a>`description`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::DebugLevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Boolean`



Default value: ``true``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="reconnection_retries"></a>`reconnection_retries`

Data type: `Integer`



Default value: `3`

##### <a name="fd_limit"></a>`fd_limit`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="command"></a>`command`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="enum_cache_timeout"></a>`enum_cache_timeout`

Data type: `Integer`



Default value: `120`

##### <a name="entry_cache_nowait_percentage"></a>`entry_cache_nowait_percentage`

Data type: `Integer`



Default value: `0`

##### <a name="entry_negative_timeout"></a>`entry_negative_timeout`

Data type: `Integer`



Default value: `15`

##### <a name="filter_users"></a>`filter_users`

Data type: `String`



Default value: `'root'`

##### <a name="filter_groups"></a>`filter_groups`

Data type: `String`



Default value: `'root'`

##### <a name="filter_users_in_groups"></a>`filter_users_in_groups`

Data type: `Boolean`



Default value: ``true``

##### <a name="override_homedir"></a>`override_homedir`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="fallback_homedir"></a>`fallback_homedir`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="override_shell"></a>`override_shell`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="vetoed_shells"></a>`vetoed_shells`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="default_shell"></a>`default_shell`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="get_domains_timeout"></a>`get_domains_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="memcache_timeout"></a>`memcache_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="user_attributes"></a>`user_attributes`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="custom_options"></a>`custom_options`

Data type: `Optional[Hash]`

If defined, this hash will be used to create the service
section instead of the parameters.  You must provide all options
in the section you want to add.  Each entry in the hash will be
added as a simple init pair key = value under the section in
the sssd.conf file.
No error checking will be performed.

Default value: ``undef``

### <a name="sssdservicepac"></a>`sssd::service::pac`

This class sets up the [pac] section of /etc/sssd.conf.

The class parameters map directly to SSSD configuration.  Full
documentation of these configuration options can be found in the
sssd.conf(5) man page.

#### Parameters

The following parameters are available in the `sssd::service::pac` class:

* [`description`](#description)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`allowed_uids`](#allowed_uids)
* [`custom_options`](#custom_options)

##### <a name="description"></a>`description`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::DebugLevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Boolean`



Default value: ``true``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="allowed_uids"></a>`allowed_uids`

Data type: `Array[String]`



Default value: `[]`

##### <a name="custom_options"></a>`custom_options`

Data type: `Optional[Hash]`

If defined, this hash will be used to create the service
section instead of the parameters.  You must provide all options
in the section you want to add.  Each entry in the hash will be
added as a simple init pair key = value under the section in
the sssd.conf file.
No error checking will be performed.

Default value: ``undef``

### <a name="sssdservicepam"></a>`sssd::service::pam`

The sssd::service::pam class.

#### Parameters

The following parameters are available in the `sssd::service::pam` class:

* [`description`](#description)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`reconnection_retries`](#reconnection_retries)
* [`command`](#command)
* [`offline_credentials_expiration`](#offline_credentials_expiration)
* [`offline_failed_login_attempts`](#offline_failed_login_attempts)
* [`offline_failed_login_delay`](#offline_failed_login_delay)
* [`pam_verbosity`](#pam_verbosity)
* [`pam_id_timeout`](#pam_id_timeout)
* [`pam_pwd_expiration_warning`](#pam_pwd_expiration_warning)
* [`get_domains_timeout`](#get_domains_timeout)
* [`pam_trusted_users`](#pam_trusted_users)
* [`pam_public_domains`](#pam_public_domains)
* [`custom_options`](#custom_options)

##### <a name="description"></a>`description`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::DebugLevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Boolean`



Default value: ``true``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="reconnection_retries"></a>`reconnection_retries`

Data type: `Integer`



Default value: `3`

##### <a name="command"></a>`command`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="offline_credentials_expiration"></a>`offline_credentials_expiration`

Data type: `Integer`



Default value: `0`

##### <a name="offline_failed_login_attempts"></a>`offline_failed_login_attempts`

Data type: `Integer`



Default value: `3`

##### <a name="offline_failed_login_delay"></a>`offline_failed_login_delay`

Data type: `Integer`



Default value: `5`

##### <a name="pam_verbosity"></a>`pam_verbosity`

Data type: `Integer`



Default value: `1`

##### <a name="pam_id_timeout"></a>`pam_id_timeout`

Data type: `Integer`



Default value: `5`

##### <a name="pam_pwd_expiration_warning"></a>`pam_pwd_expiration_warning`

Data type: `Integer`



Default value: `7`

##### <a name="get_domains_timeout"></a>`get_domains_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="pam_trusted_users"></a>`pam_trusted_users`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="pam_public_domains"></a>`pam_public_domains`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="custom_options"></a>`custom_options`

Data type: `Optional[Hash]`



Default value: ``undef``

### <a name="sssdservicessh"></a>`sssd::service::ssh`

This class sets up the [ssh] section of /etc/sssd.conf.

The class parameters map directly to SSSD configuration.  Full
documentation of these configuration options can be found in the
sssd.conf(5) man page.

#### Parameters

The following parameters are available in the `sssd::service::ssh` class:

* [`description`](#description)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`ssh_hash_known_hosts`](#ssh_hash_known_hosts)
* [`ssh_known_hosts_timeout`](#ssh_known_hosts_timeout)
* [`custom_options`](#custom_options)

##### <a name="description"></a>`description`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::DebugLevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Boolean`



Default value: ``true``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="ssh_hash_known_hosts"></a>`ssh_hash_known_hosts`

Data type: `Boolean`



Default value: ``true``

##### <a name="ssh_known_hosts_timeout"></a>`ssh_known_hosts_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="custom_options"></a>`custom_options`

Data type: `Optional[Hash]`

If defined, this hash will be used to create the service
section instead of the parameters.  You must provide all options
in the section you want to add.  Each entry in the hash will be
added as a simple init pair key = value under the section in
the sssd.conf file.
No error checking will be performed.

Default value: ``undef``

### <a name="sssdservicesudo"></a>`sssd::service::sudo`

This class sets up the [sudo] section of /etc/sssd.conf.

The class parameters map directly to SSSD configuration.  Full
documentation of these configuration options can be found in the
sssd.conf(5) man page.

#### Parameters

The following parameters are available in the `sssd::service::sudo` class:

* [`description`](#description)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`sudo_threshold`](#sudo_threshold)
* [`sudo_timed`](#sudo_timed)
* [`custom_options`](#custom_options)

##### <a name="description"></a>`description`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::Debuglevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Boolean`



Default value: ``true``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="sudo_threshold"></a>`sudo_threshold`

Data type: `Integer[1]`



Default value: `50`

##### <a name="sudo_timed"></a>`sudo_timed`

Data type: `Boolean`



Default value: ``false``

##### <a name="custom_options"></a>`custom_options`

Data type: `Optional[Hash]`

If defined, this hash will be used to create the service
section instead of the parameters.  You must provide all options
in the section you want to add.  Each entry in the hash will be
added as a simple init pair
key = value
under the section in the sssd.conf file.
No error checking will be performed.

Default value: ``undef``

## Defined types

### <a name="sssdconfigentry"></a>`sssd::config::entry`

Add an entry to the /etc/sssd/conf.d directory

#### Parameters

The following parameters are available in the `sssd::config::entry` defined type:

* [`name`](#name)
* [`content`](#content)
* [`order`](#order)

##### <a name="name"></a>`name`

A unique name that will be used for generating the target filename

Should not be fully qualified

##### <a name="content"></a>`content`

Data type: `String`

The content of the target file

##### <a name="order"></a>`order`

Data type: `Integer[0]`



Default value: `50`

### <a name="sssddomain"></a>`sssd::domain`

Define: sssd::domain

This define sets up a domain section of /etc/sssd.conf. This domain will be
named after '$name' and should be listed in your main sssd.conf if you wish
to activate it.

You will need to call the associated provider segments to make this fully
functional.

It is entirely possible to make a configuration file that is complete
nonsense by failing to set the correct combinations of providers. See the
SSSD documentation for details.

When you call the associated providers, you should be sure to name them based
on the name of this domain.

Full documentation of the parameters that map directly to SSSD
configuration options can be found in the sssd.conf(5) man page.

#### Parameters

The following parameters are available in the `sssd::domain` defined type:

* [`name`](#name)
* [`id_provider`](#id_provider)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`description`](#description)
* [`min_id`](#min_id)
* [`max_id`](#max_id)
* [`enumerate`](#enumerate)
* [`subdomain_enumerate`](#subdomain_enumerate)
* [`force_timeout`](#force_timeout)
* [`entry_cache_timeout`](#entry_cache_timeout)
* [`entry_cache_user_timeout`](#entry_cache_user_timeout)
* [`entry_cache_group_timeout`](#entry_cache_group_timeout)
* [`entry_cache_netgroup_timeout`](#entry_cache_netgroup_timeout)
* [`entry_cache_service_timeout`](#entry_cache_service_timeout)
* [`entry_cache_sudo_timeout`](#entry_cache_sudo_timeout)
* [`entry_cache_autofs_timeout`](#entry_cache_autofs_timeout)
* [`entry_cache_ssh_host_timeout`](#entry_cache_ssh_host_timeout)
* [`refresh_expired_interval`](#refresh_expired_interval)
* [`cache_credentials`](#cache_credentials)
* [`account_cache_expiration`](#account_cache_expiration)
* [`pwd_expiration_warning`](#pwd_expiration_warning)
* [`use_fully_qualified_names`](#use_fully_qualified_names)
* [`ignore_group_members`](#ignore_group_members)
* [`access_provider`](#access_provider)
* [`auth_provider`](#auth_provider)
* [`chpass_provider`](#chpass_provider)
* [`sudo_provider`](#sudo_provider)
* [`selinux_provider`](#selinux_provider)
* [`subdomains_provider`](#subdomains_provider)
* [`autofs_provider`](#autofs_provider)
* [`hostid_provider`](#hostid_provider)
* [`re_expression`](#re_expression)
* [`full_name_format`](#full_name_format)
* [`lookup_family_order`](#lookup_family_order)
* [`dns_resolver_timeout`](#dns_resolver_timeout)
* [`dns_discovery_domain`](#dns_discovery_domain)
* [`override_gid`](#override_gid)
* [`case_sensitive`](#case_sensitive)
* [`proxy_fast_alias`](#proxy_fast_alias)
* [`realmd_tags`](#realmd_tags)
* [`proxy_pam_target`](#proxy_pam_target)
* [`proxy_lib_name`](#proxy_lib_name)

##### <a name="name"></a>`name`

The name of the domain.
This will be placed at [domain/$name] in the configuration file.

##### <a name="id_provider"></a>`id_provider`

Data type: `Sssd::IdProvider`



##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::DebugLevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Boolean`



Default value: ``true``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="description"></a>`description`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="min_id"></a>`min_id`

Data type: `Integer[0]`



Default value: `1`

##### <a name="max_id"></a>`max_id`

Data type: `Integer[0]`



Default value: `0`

##### <a name="enumerate"></a>`enumerate`

Data type: `Boolean`



Default value: ``false``

##### <a name="subdomain_enumerate"></a>`subdomain_enumerate`

Data type: `Boolean`



Default value: ``false``

##### <a name="force_timeout"></a>`force_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="entry_cache_timeout"></a>`entry_cache_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="entry_cache_user_timeout"></a>`entry_cache_user_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="entry_cache_group_timeout"></a>`entry_cache_group_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="entry_cache_netgroup_timeout"></a>`entry_cache_netgroup_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="entry_cache_service_timeout"></a>`entry_cache_service_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="entry_cache_sudo_timeout"></a>`entry_cache_sudo_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="entry_cache_autofs_timeout"></a>`entry_cache_autofs_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="entry_cache_ssh_host_timeout"></a>`entry_cache_ssh_host_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="refresh_expired_interval"></a>`refresh_expired_interval`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="cache_credentials"></a>`cache_credentials`

Data type: `Boolean`



Default value: ``false``

##### <a name="account_cache_expiration"></a>`account_cache_expiration`

Data type: `Integer[0]`



Default value: `0`

##### <a name="pwd_expiration_warning"></a>`pwd_expiration_warning`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="use_fully_qualified_names"></a>`use_fully_qualified_names`

Data type: `Boolean`



Default value: ``false``

##### <a name="ignore_group_members"></a>`ignore_group_members`

Data type: `Boolean`



Default value: ``true``

##### <a name="access_provider"></a>`access_provider`

Data type: `Optional[Sssd::AccessProvider]`



Default value: ``undef``

##### <a name="auth_provider"></a>`auth_provider`

Data type: `Optional[Sssd::AuthProvider]`



Default value: ``undef``

##### <a name="chpass_provider"></a>`chpass_provider`

Data type: `Optional[Sssd::ChpassProvider]`



Default value: ``undef``

##### <a name="sudo_provider"></a>`sudo_provider`

Data type: `Optional[Enum['ldap', 'ipa','ad','none']]`



Default value: ``undef``

##### <a name="selinux_provider"></a>`selinux_provider`

Data type: `Optional[Enum['ipa', 'none']]`



Default value: ``undef``

##### <a name="subdomains_provider"></a>`subdomains_provider`

Data type: `Optional[Enum['ipa', 'ad','none']]`



Default value: ``undef``

##### <a name="autofs_provider"></a>`autofs_provider`

Data type: `Optional[Enum['ldap', 'ipa','none']]`



Default value: ``undef``

##### <a name="hostid_provider"></a>`hostid_provider`

Data type: `Optional[Enum['ipa', 'none']]`



Default value: ``undef``

##### <a name="re_expression"></a>`re_expression`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="full_name_format"></a>`full_name_format`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="lookup_family_order"></a>`lookup_family_order`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="dns_resolver_timeout"></a>`dns_resolver_timeout`

Data type: `Integer[0]`



Default value: `5`

##### <a name="dns_discovery_domain"></a>`dns_discovery_domain`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="override_gid"></a>`override_gid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="case_sensitive"></a>`case_sensitive`

Data type: `Variant[Boolean,Enum['preserving']]`



Default value: ``true``

##### <a name="proxy_fast_alias"></a>`proxy_fast_alias`

Data type: `Boolean`



Default value: ``false``

##### <a name="realmd_tags"></a>`realmd_tags`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="proxy_pam_target"></a>`proxy_pam_target`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="proxy_lib_name"></a>`proxy_lib_name`

Data type: `Optional[String]`



Default value: ``undef``

### <a name="sssdproviderad"></a>`sssd::provider::ad`

NOTE: You MUST connect the system to the domain prior to using this defined type.

Any parameter not explicitly documented directly follows the documentation
from sssd-ad(5).

* **See also**
  * sssd-ad(5)

#### Parameters

The following parameters are available in the `sssd::provider::ad` defined type:

* [`ad_domain`](#ad_domain)
* [`ad_enabled_domains`](#ad_enabled_domains)
* [`ad_servers`](#ad_servers)
* [`ad_backup_servers`](#ad_backup_servers)
* [`ad_hostname`](#ad_hostname)
* [`ad_enable_dns_sites`](#ad_enable_dns_sites)
* [`ad_access_filters`](#ad_access_filters)
* [`ad_site`](#ad_site)
* [`ad_enable_gc`](#ad_enable_gc)
* [`ad_gpo_access_control`](#ad_gpo_access_control)
* [`ad_gpo_cache_timeout`](#ad_gpo_cache_timeout)
* [`ad_gpo_map_interactive`](#ad_gpo_map_interactive)
* [`ad_gpo_map_remote_interactive`](#ad_gpo_map_remote_interactive)
* [`ad_gpo_map_network`](#ad_gpo_map_network)
* [`ad_gpo_map_batch`](#ad_gpo_map_batch)
* [`ad_gpo_map_service`](#ad_gpo_map_service)
* [`ad_gpo_map_permit`](#ad_gpo_map_permit)
* [`ad_gpo_map_deny`](#ad_gpo_map_deny)
* [`ad_gpo_default_right`](#ad_gpo_default_right)
* [`ad_gpo_implicit_deny`](#ad_gpo_implicit_deny)
* [`ad_gpo_ignore_unreadable`](#ad_gpo_ignore_unreadable)
* [`ad_maximum_machine_account_password_age`](#ad_maximum_machine_account_password_age)
* [`ad_machine_account_password_renewal_opts`](#ad_machine_account_password_renewal_opts)
* [`default_shell`](#default_shell)
* [`dyndns_update`](#dyndns_update)
* [`dyndns_ttl`](#dyndns_ttl)
* [`dyndns_ifaces`](#dyndns_ifaces)
* [`dyndns_refresh_interval`](#dyndns_refresh_interval)
* [`dyndns_update_ptr`](#dyndns_update_ptr)
* [`dyndns_force_tcp`](#dyndns_force_tcp)
* [`dyndns_server`](#dyndns_server)
* [`override_homedir`](#override_homedir)
* [`fallback_homedir`](#fallback_homedir)
* [`homedir_substring`](#homedir_substring)
* [`krb5_realm`](#krb5_realm)
* [`krb5_use_enterprise_principal`](#krb5_use_enterprise_principal)
* [`krb5_store_password_if_offline`](#krb5_store_password_if_offline)
* [`krb5_confd_path`](#krb5_confd_path)
* [`ldap_id_mapping`](#ldap_id_mapping)
* [`ldap_schema`](#ldap_schema)
* [`ldap_idmap_range_min`](#ldap_idmap_range_min)
* [`ldap_idmap_range_max`](#ldap_idmap_range_max)
* [`ldap_idmap_range_size`](#ldap_idmap_range_size)
* [`ldap_idmap_default_domain_sid`](#ldap_idmap_default_domain_sid)
* [`ldap_idmap_default_domain`](#ldap_idmap_default_domain)
* [`ldap_idmap_autorid_compat`](#ldap_idmap_autorid_compat)
* [`ldap_idmap_helper_table_size`](#ldap_idmap_helper_table_size)
* [`ldap_use_tokengroups`](#ldap_use_tokengroups)
* [`ldap_group_objectsid`](#ldap_group_objectsid)
* [`ldap_user_objectsid`](#ldap_user_objectsid)

##### <a name="ad_domain"></a>`ad_domain`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ad_enabled_domains"></a>`ad_enabled_domains`

Data type: `Optional[Array[String[1],1]]`

An explicit list of AD enabled domains

* An error will be raised if ``ad_domain`` is specified and not in this
  list

Default value: ``undef``

##### <a name="ad_servers"></a>`ad_servers`

Data type: `Optional[Array[Variant[Simplib::Hostname, Enum['_srv_']]]]`

A list of AD servers in failover order

* Ignored if ``autodiscovery`` is enabled

Default value: ``undef``

##### <a name="ad_backup_servers"></a>`ad_backup_servers`

Data type: `Optional[Array[Simplib::Hostname,1]]`

A list of AD backup servers in failover order

* Ignored if ``autodiscovery`` is enabled

Default value: ``undef``

##### <a name="ad_hostname"></a>`ad_hostname`

Data type: `Optional[Simplib::Hostname]`



Default value: ``undef``

##### <a name="ad_enable_dns_sites"></a>`ad_enable_dns_sites`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ad_access_filters"></a>`ad_access_filters`

Data type: `Optional[Array[String[1],1]]`

A list of access filters for the system

Default value: ``undef``

##### <a name="ad_site"></a>`ad_site`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ad_enable_gc"></a>`ad_enable_gc`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ad_gpo_access_control"></a>`ad_gpo_access_control`

Data type: `Optional[Enum['disabled','enforcing','permissive']]`



Default value: ``undef``

##### <a name="ad_gpo_cache_timeout"></a>`ad_gpo_cache_timeout`

Data type: `Optional[Integer[1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_interactive"></a>`ad_gpo_map_interactive`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_remote_interactive"></a>`ad_gpo_map_remote_interactive`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_network"></a>`ad_gpo_map_network`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_batch"></a>`ad_gpo_map_batch`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_service"></a>`ad_gpo_map_service`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_permit"></a>`ad_gpo_map_permit`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_deny"></a>`ad_gpo_map_deny`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="ad_gpo_default_right"></a>`ad_gpo_default_right`

Data type: `Optional[Sssd::ADDefaultRight]`



Default value: ``undef``

##### <a name="ad_gpo_implicit_deny"></a>`ad_gpo_implicit_deny`

Data type: `Optional[Boolean]`

(new in sssd V2.0 and later)

Default value: ``undef``

##### <a name="ad_gpo_ignore_unreadable"></a>`ad_gpo_ignore_unreadable`

Data type: `Optional[Boolean]`

(new in sssd V2.0 and later)

Default value: ``undef``

##### <a name="ad_maximum_machine_account_password_age"></a>`ad_maximum_machine_account_password_age`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ad_machine_account_password_renewal_opts"></a>`ad_machine_account_password_renewal_opts`

Data type: `Optional[Pattern['^\d+:\d+$']]`



Default value: ``undef``

##### <a name="default_shell"></a>`default_shell`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="dyndns_update"></a>`dyndns_update`

Data type: `Optional[Boolean]`



Default value: ``true``

##### <a name="dyndns_ttl"></a>`dyndns_ttl`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="dyndns_ifaces"></a>`dyndns_ifaces`

Data type: `Optional[Array[String[1],1]]`

List of interfaces whose IP Addresses should be used for dynamic DNS
updates.  Used for the dyndns_iface setting.

* Has no effect if ``dyndns_update`` is not set to ``true``

Default value: ``undef``

##### <a name="dyndns_refresh_interval"></a>`dyndns_refresh_interval`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="dyndns_update_ptr"></a>`dyndns_update_ptr`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="dyndns_force_tcp"></a>`dyndns_force_tcp`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="dyndns_server"></a>`dyndns_server`

Data type: `Optional[Simplib::Hostname]`



Default value: ``undef``

##### <a name="override_homedir"></a>`override_homedir`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="fallback_homedir"></a>`fallback_homedir`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="homedir_substring"></a>`homedir_substring`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="krb5_realm"></a>`krb5_realm`

Data type: `Optional[String[1]]`



Default value: `$ad_domain`

##### <a name="krb5_use_enterprise_principal"></a>`krb5_use_enterprise_principal`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="krb5_store_password_if_offline"></a>`krb5_store_password_if_offline`

Data type: `Optional[Boolean]`



Default value: ``false``

##### <a name="krb5_confd_path"></a>`krb5_confd_path`

Data type: `Optional[Variant[Enum['none'],Stdlib::Absolutepath]]`



Default value: ``undef``

##### <a name="ldap_id_mapping"></a>`ldap_id_mapping`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_schema"></a>`ldap_schema`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_idmap_range_min"></a>`ldap_idmap_range_min`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_idmap_range_max"></a>`ldap_idmap_range_max`

Data type: `Optional[Integer[1]]`



Default value: ``undef``

##### <a name="ldap_idmap_range_size"></a>`ldap_idmap_range_size`

Data type: `Optional[Integer[1]]`



Default value: ``undef``

##### <a name="ldap_idmap_default_domain_sid"></a>`ldap_idmap_default_domain_sid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_idmap_default_domain"></a>`ldap_idmap_default_domain`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_idmap_autorid_compat"></a>`ldap_idmap_autorid_compat`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_idmap_helper_table_size"></a>`ldap_idmap_helper_table_size`

Data type: `Optional[Integer[1]]`



Default value: ``undef``

##### <a name="ldap_use_tokengroups"></a>`ldap_use_tokengroups`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_group_objectsid"></a>`ldap_group_objectsid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_objectsid"></a>`ldap_user_objectsid`

Data type: `Optional[String[1]]`



Default value: ``undef``

### <a name="sssdproviderfiles"></a>`sssd::provider::files`

NOTE: This defined type has no effect on SSSD < 1.16.0

$name should be the name of the associated domain in sssd.conf.

This is not necessary for the file provider unless you want to use
files other then /etc/passwd and /etc/group

See man 'sssd-files' for additional information.

#### Parameters

The following parameters are available in the `sssd::provider::files` defined type:

* [`name`](#name)
* [`passwd_files`](#passwd_files)
* [`group_files`](#group_files)

##### <a name="name"></a>`name`

The name of the associated domain section in the configuration file.

##### <a name="passwd_files"></a>`passwd_files`

Data type: `Optional[Array[Stdlib::Absolutepath]]`



Default value: ``undef``

##### <a name="group_files"></a>`group_files`

Data type: `Optional[Array[Stdlib::Absolutepath]]`



Default value: ``undef``

### <a name="sssdprovideripa"></a>`sssd::provider::ipa`

This define sets up the 'ipa' provider section of a particular domain.
$name should be the name of the associated domain in sssd.conf.

See sssd-ipa.conf(5) for additional information.

Regarding: POODLE - CVE-2014-3566

The tls_cipher_suite variable is set to HIGH:-SSLv2 by default because
OpenLDAP cannot set the SSL provider natively. By default, it will run TLSv1
but cannot handle TLSv1.2 therefore the SSLv3 ciphers cannot be eliminated.
Take care to ensure that your clients only connect with TLSv1 if possible.

#### Parameters

The following parameters are available in the `sssd::provider::ipa` defined type:

* [`name`](#name)
* [`ipa_domain`](#ipa_domain)
* [`ipa_server`](#ipa_server)
* [`ipa_backup_server`](#ipa_backup_server)
* [`ipa_enable_dns_sites`](#ipa_enable_dns_sites)
* [`ipa_hostname`](#ipa_hostname)
* [`ipa_server_mode`](#ipa_server_mode)
* [`dyndns_auth`](#dyndns_auth)
* [`dyndns_force_tcp`](#dyndns_force_tcp)
* [`dyndns_iface`](#dyndns_iface)
* [`dyndns_refresh_interval`](#dyndns_refresh_interval)
* [`dyndns_server`](#dyndns_server)
* [`dyndns_ttl`](#dyndns_ttl)
* [`dyndns_update`](#dyndns_update)
* [`dyndns_update_ptr`](#dyndns_update_ptr)
* [`ipa_automount_location`](#ipa_automount_location)
* [`ipa_hbac_refresh`](#ipa_hbac_refresh)
* [`ipa_hbac_search_base`](#ipa_hbac_search_base)
* [`ipa_hbac_selinux`](#ipa_hbac_selinux)
* [`ipa_host_search_base`](#ipa_host_search_base)
* [`ipa_master_domains_search_base`](#ipa_master_domains_search_base)
* [`ipa_selinux_search_base`](#ipa_selinux_search_base)
* [`ipa_subdomains_search_base`](#ipa_subdomains_search_base)
* [`ipa_views_search_base`](#ipa_views_search_base)
* [`krb5_confd_path`](#krb5_confd_path)
* [`krb5_realm`](#krb5_realm)
* [`krb5_store_password_if_offline`](#krb5_store_password_if_offline)
* [`ldap_tls_cacert`](#ldap_tls_cacert)
* [`ldap_tls_cipher_suite`](#ldap_tls_cipher_suite)
* [`use_service_discovery`](#use_service_discovery)

##### <a name="name"></a>`name`



##### <a name="ipa_domain"></a>`ipa_domain`

Data type: `String[1]`



##### <a name="ipa_server"></a>`ipa_server`

Data type: `Array[Simplib::Host]`



##### <a name="ipa_backup_server"></a>`ipa_backup_server`

Data type: `Optional[Array[Simplib::Host]]`



Default value: ``undef``

##### <a name="ipa_enable_dns_sites"></a>`ipa_enable_dns_sites`

Data type: `Boolean`



Default value: ``false``

##### <a name="ipa_hostname"></a>`ipa_hostname`

Data type: `Simplib::Hostname`



Default value: `$facts['fqdn']`

##### <a name="ipa_server_mode"></a>`ipa_server_mode`

Data type: `Boolean`



Default value: ``false``

##### <a name="dyndns_auth"></a>`dyndns_auth`

Data type: `Enum['none','GSS-TSIG']`



Default value: `'GSS-TSIG'`

##### <a name="dyndns_force_tcp"></a>`dyndns_force_tcp`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="dyndns_iface"></a>`dyndns_iface`

Data type: `Optional[Array[String[1]]]`



Default value: ``undef``

##### <a name="dyndns_refresh_interval"></a>`dyndns_refresh_interval`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="dyndns_server"></a>`dyndns_server`

Data type: `Optional[Simplib::Host]`



Default value: ``undef``

##### <a name="dyndns_ttl"></a>`dyndns_ttl`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="dyndns_update"></a>`dyndns_update`

Data type: `Boolean`



Default value: ``true``

##### <a name="dyndns_update_ptr"></a>`dyndns_update_ptr`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ipa_automount_location"></a>`ipa_automount_location`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_hbac_refresh"></a>`ipa_hbac_refresh`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ipa_hbac_search_base"></a>`ipa_hbac_search_base`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_hbac_selinux"></a>`ipa_hbac_selinux`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ipa_host_search_base"></a>`ipa_host_search_base`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_master_domains_search_base"></a>`ipa_master_domains_search_base`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_selinux_search_base"></a>`ipa_selinux_search_base`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_subdomains_search_base"></a>`ipa_subdomains_search_base`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_views_search_base"></a>`ipa_views_search_base`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="krb5_confd_path"></a>`krb5_confd_path`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: ``undef``

##### <a name="krb5_realm"></a>`krb5_realm`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="krb5_store_password_if_offline"></a>`krb5_store_password_if_offline`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_tls_cacert"></a>`ldap_tls_cacert`

Data type: `Stdlib::AbsolutePath`



Default value: `'/etc/ipa/ca.crt'`

##### <a name="ldap_tls_cipher_suite"></a>`ldap_tls_cipher_suite`

Data type: `Array[String]`



Default value: `['HIGH','-SSLv2']`

##### <a name="use_service_discovery"></a>`use_service_discovery`

Data type: `Boolean`

Whether to add '_srv_' to the list of IPA servers,
thereby enabling service discovery of these servers

Default value: ``true``

### <a name="sssdproviderkrb5"></a>`sssd::provider::krb5`

Define: sssd::provider::krb5

This define sets up the 'krb5' provider section of a particular domain.
$name should be the name of the associated domain in sssd.conf.

See sssd-krb5.conf(5) for additional information.

#### Parameters

The following parameters are available in the `sssd::provider::krb5` defined type:

* [`name`](#name)
* [`krb5_server`](#krb5_server)
* [`krb5_realm`](#krb5_realm)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`krb5_kpasswd`](#krb5_kpasswd)
* [`krb5_ccachedir`](#krb5_ccachedir)
* [`krb5_ccname_template`](#krb5_ccname_template)
* [`krb5_auth_timeout`](#krb5_auth_timeout)
* [`krb5_validate`](#krb5_validate)
* [`krb5_keytab`](#krb5_keytab)
* [`krb5_store_password_if_offline`](#krb5_store_password_if_offline)
* [`krb5_renewable_lifetime`](#krb5_renewable_lifetime)
* [`krb5_lifetime`](#krb5_lifetime)
* [`krb5_renew_interval`](#krb5_renew_interval)
* [`krb5_use_fast`](#krb5_use_fast)

##### <a name="name"></a>`name`

The name of the associated domain section in the configuration file.

##### <a name="krb5_server"></a>`krb5_server`

Data type: `Simplib::Host`



##### <a name="krb5_realm"></a>`krb5_realm`

Data type: `String`



##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::DebugLevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Boolean`



Default value: ``true``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="krb5_kpasswd"></a>`krb5_kpasswd`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="krb5_ccachedir"></a>`krb5_ccachedir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="krb5_ccname_template"></a>`krb5_ccname_template`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="krb5_auth_timeout"></a>`krb5_auth_timeout`

Data type: `Integer`



Default value: `15`

##### <a name="krb5_validate"></a>`krb5_validate`

Data type: `Boolean`



Default value: ``false``

##### <a name="krb5_keytab"></a>`krb5_keytab`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="krb5_store_password_if_offline"></a>`krb5_store_password_if_offline`

Data type: `Boolean`



Default value: ``false``

##### <a name="krb5_renewable_lifetime"></a>`krb5_renewable_lifetime`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="krb5_lifetime"></a>`krb5_lifetime`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="krb5_renew_interval"></a>`krb5_renew_interval`

Data type: `Integer`



Default value: `0`

##### <a name="krb5_use_fast"></a>`krb5_use_fast`

Data type: `Optional[Enum['never','try','demand']]`



Default value: ``undef``

### <a name="sssdproviderldap"></a>`sssd::provider::ldap`

Define: sssd::provider::ldap

This define sets up the 'ldap' provider section of a particular domain.
$name should be the name of the associated domain in sssd.conf.

Configuration notes:

* See sssd-ldap.conf(5) for additional information.
* Be careful with the following configuration:
    * ldap_netgroup_search_base
    * ldap_user_search_base
    * ldap_group_search_base
    * ldap_sudo_search_base
    * ldap_autofs_search_base

* Be sure to read the man page for the following advanced
  configuration:
    * ldap_idmap_range_min
    * ldap_idmap_range_max
    * ldap_idmap_range_size
    * ldap_idmap_default_domain_sid
    * ldap_idmap_default_domain
    * ldap_idmap_autorid_compat


Regarding: POODLE - CVE-2014-3566

The tls_cipher_suite variable is set to HIGH:-SSLv2 by default because
OpenLDAP cannot set the SSL provider natively. By default, it will run TLSv1
but cannot handle TLSv1.2 therefore the SSLv3 ciphers cannot be eliminated.
Take care to ensure that your clients only connect with TLSv1 if possible.

Advanced Configuration - Read the man page

#### Parameters

The following parameters are available in the `sssd::provider::ldap` defined type:

* [`name`](#name)
* [`strip_128_bit_ciphers`](#strip_128_bit_ciphers)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`ldap_uri`](#ldap_uri)
* [`ldap_backup_uri`](#ldap_backup_uri)
* [`ldap_chpass_uri`](#ldap_chpass_uri)
* [`ldap_chpass_backup_uri`](#ldap_chpass_backup_uri)
* [`ldap_chpass_update_last_change`](#ldap_chpass_update_last_change)
* [`ldap_search_base`](#ldap_search_base)
* [`ldap_schema`](#ldap_schema)
* [`ldap_default_bind_dn`](#ldap_default_bind_dn)
* [`ldap_default_authtok_type`](#ldap_default_authtok_type)
* [`ldap_default_authtok`](#ldap_default_authtok)
* [`ldap_user_object_class`](#ldap_user_object_class)
* [`ldap_user_name`](#ldap_user_name)
* [`ldap_user_uid_number`](#ldap_user_uid_number)
* [`ldap_user_gid_number`](#ldap_user_gid_number)
* [`ldap_user_gecos`](#ldap_user_gecos)
* [`ldap_user_home_directory`](#ldap_user_home_directory)
* [`ldap_user_shell`](#ldap_user_shell)
* [`ldap_user_uuid`](#ldap_user_uuid)
* [`ldap_user_objectsid`](#ldap_user_objectsid)
* [`ldap_user_modify_timestamp`](#ldap_user_modify_timestamp)
* [`ldap_user_shadow_last_change`](#ldap_user_shadow_last_change)
* [`ldap_user_shadow_min`](#ldap_user_shadow_min)
* [`ldap_user_shadow_max`](#ldap_user_shadow_max)
* [`ldap_user_shadow_warning`](#ldap_user_shadow_warning)
* [`ldap_user_shadow_inactive`](#ldap_user_shadow_inactive)
* [`ldap_user_shadow_expire`](#ldap_user_shadow_expire)
* [`ldap_user_krb_last_pwd_change`](#ldap_user_krb_last_pwd_change)
* [`ldap_user_krb_password_expiration`](#ldap_user_krb_password_expiration)
* [`ldap_user_ad_account_expires`](#ldap_user_ad_account_expires)
* [`ldap_user_ad_user_account_control`](#ldap_user_ad_user_account_control)
* [`ldap_ns_account_lock`](#ldap_ns_account_lock)
* [`ldap_user_nds_login_disabled`](#ldap_user_nds_login_disabled)
* [`ldap_user_nds_login_expiration_time`](#ldap_user_nds_login_expiration_time)
* [`ldap_user_nds_login_allowed_time_map`](#ldap_user_nds_login_allowed_time_map)
* [`ldap_user_principal`](#ldap_user_principal)
* [`ldap_user_extra_attrs`](#ldap_user_extra_attrs)
* [`ldap_user_ssh_public_key`](#ldap_user_ssh_public_key)
* [`ldap_force_upper_case_realm`](#ldap_force_upper_case_realm)
* [`ldap_enumeration_refresh_timeout`](#ldap_enumeration_refresh_timeout)
* [`ldap_purge_cache_timeout`](#ldap_purge_cache_timeout)
* [`ldap_user_fullname`](#ldap_user_fullname)
* [`ldap_user_member_of`](#ldap_user_member_of)
* [`ldap_user_authorized_service`](#ldap_user_authorized_service)
* [`ldap_user_authorized_host`](#ldap_user_authorized_host)
* [`ldap_group_object_class`](#ldap_group_object_class)
* [`ldap_group_name`](#ldap_group_name)
* [`ldap_group_gid_number`](#ldap_group_gid_number)
* [`ldap_group_member`](#ldap_group_member)
* [`ldap_group_uuid`](#ldap_group_uuid)
* [`ldap_group_objectsid`](#ldap_group_objectsid)
* [`ldap_group_modify_timestamp`](#ldap_group_modify_timestamp)
* [`ldap_group_type`](#ldap_group_type)
* [`ldap_group_nesting_level`](#ldap_group_nesting_level)
* [`ldap_groups_use_matching_rule_in_chain`](#ldap_groups_use_matching_rule_in_chain)
* [`ldap_initgroups_use_matching_rule_in_chain`](#ldap_initgroups_use_matching_rule_in_chain)
* [`ldap_use_tokengroups`](#ldap_use_tokengroups)
* [`ldap_netgroup_object_class`](#ldap_netgroup_object_class)
* [`ldap_netgroup_name`](#ldap_netgroup_name)
* [`ldap_netgroup_member`](#ldap_netgroup_member)
* [`ldap_netgroup_triple`](#ldap_netgroup_triple)
* [`ldap_netgroup_uuid`](#ldap_netgroup_uuid)
* [`ldap_netgroup_modify_timestamp`](#ldap_netgroup_modify_timestamp)
* [`ldap_service_name`](#ldap_service_name)
* [`ldap_service_port`](#ldap_service_port)
* [`ldap_service_proto`](#ldap_service_proto)
* [`ldap_service_search_base`](#ldap_service_search_base)
* [`ldap_search_timeout`](#ldap_search_timeout)
* [`ldap_enumeration_search_timeout`](#ldap_enumeration_search_timeout)
* [`ldap_network_timeout`](#ldap_network_timeout)
* [`ldap_opt_timeout`](#ldap_opt_timeout)
* [`ldap_connection_expire_timeout`](#ldap_connection_expire_timeout)
* [`ldap_page_size`](#ldap_page_size)
* [`ldap_disable_paging`](#ldap_disable_paging)
* [`ldap_disable_range_retrieval`](#ldap_disable_range_retrieval)
* [`ldap_sasl_minssf`](#ldap_sasl_minssf)
* [`ldap_deref_threshold`](#ldap_deref_threshold)
* [`ldap_tls_reqcert`](#ldap_tls_reqcert)
* [`ldap_tls_cacert`](#ldap_tls_cacert)
* [`app_pki_ca_dir`](#app_pki_ca_dir)
* [`app_pki_key`](#app_pki_key)
* [`app_pki_cert`](#app_pki_cert)
* [`strip_128_bit_ciphers`](#strip_128_bit_ciphers)
* [`ldap_tls_cipher_suite`](#ldap_tls_cipher_suite)
* [`ldap_id_use_start_tls`](#ldap_id_use_start_tls)
* [`ldap_id_mapping`](#ldap_id_mapping)
* [`ldap_min_id`](#ldap_min_id)
* [`ldap_max_id`](#ldap_max_id)
* [`ldap_sasl_mech`](#ldap_sasl_mech)
* [`ldap_sasl_authid`](#ldap_sasl_authid)
* [`ldap_sasl_realm`](#ldap_sasl_realm)
* [`ldap_sasl_canonicalize`](#ldap_sasl_canonicalize)
* [`ldap_krb5_keytab`](#ldap_krb5_keytab)
* [`ldap_krb5_init_creds`](#ldap_krb5_init_creds)
* [`ldap_krb5_ticket_lifetime`](#ldap_krb5_ticket_lifetime)
* [`krb5_server`](#krb5_server)
* [`krb5_backup_server`](#krb5_backup_server)
* [`krb5_realm`](#krb5_realm)
* [`krb5_canonicalize`](#krb5_canonicalize)
* [`krb5_use_kdcinfo`](#krb5_use_kdcinfo)
* [`ldap_pwd_policy`](#ldap_pwd_policy)
* [`ldap_referrals`](#ldap_referrals)
* [`ldap_dns_service_name`](#ldap_dns_service_name)
* [`ldap_chpass_dns_service_name`](#ldap_chpass_dns_service_name)
* [`ldap_access_filter`](#ldap_access_filter)
* [`ldap_account_expire_policy`](#ldap_account_expire_policy)
* [`ldap_access_order`](#ldap_access_order)
* [`ldap_pwdlockout_dn`](#ldap_pwdlockout_dn)
* [`ldap_deref`](#ldap_deref)
* [`ldap_sudorule_object_class`](#ldap_sudorule_object_class)
* [`ldap_sudorule_name`](#ldap_sudorule_name)
* [`ldap_sudorule_command`](#ldap_sudorule_command)
* [`ldap_sudorule_host`](#ldap_sudorule_host)
* [`ldap_sudorule_user`](#ldap_sudorule_user)
* [`ldap_sudorule_option`](#ldap_sudorule_option)
* [`ldap_sudorule_runasuser`](#ldap_sudorule_runasuser)
* [`ldap_sudorule_runasgroup`](#ldap_sudorule_runasgroup)
* [`ldap_sudorule_notbefore`](#ldap_sudorule_notbefore)
* [`ldap_sudorule_notafter`](#ldap_sudorule_notafter)
* [`ldap_sudorule_order`](#ldap_sudorule_order)
* [`ldap_sudo_full_refresh_interval`](#ldap_sudo_full_refresh_interval)
* [`ldap_sudo_smart_refresh_interval`](#ldap_sudo_smart_refresh_interval)
* [`ldap_sudo_use_host_filter`](#ldap_sudo_use_host_filter)
* [`ldap_sudo_hostnames`](#ldap_sudo_hostnames)
* [`ldap_sudo_ip`](#ldap_sudo_ip)
* [`ldap_sudo_include_netgroups`](#ldap_sudo_include_netgroups)
* [`ldap_sudo_include_regexp`](#ldap_sudo_include_regexp)
* [`ldap_autofs_map_master_name`](#ldap_autofs_map_master_name)
* [`ldap_autofs_map_object_class`](#ldap_autofs_map_object_class)
* [`ldap_autofs_map_name`](#ldap_autofs_map_name)
* [`ldap_autofs_entry_object_class`](#ldap_autofs_entry_object_class)
* [`ldap_autofs_entry_key`](#ldap_autofs_entry_key)
* [`ldap_autofs_entry_value`](#ldap_autofs_entry_value)
* [`ldap_netgroup_search_base`](#ldap_netgroup_search_base)
* [`ldap_user_search_base`](#ldap_user_search_base)
* [`ldap_group_search_base`](#ldap_group_search_base)
* [`ldap_sudo_search_base`](#ldap_sudo_search_base)
* [`ldap_autofs_search_base`](#ldap_autofs_search_base)
* [`ldap_idmap_range_min`](#ldap_idmap_range_min)
* [`ldap_idmap_range_max`](#ldap_idmap_range_max)
* [`ldap_idmap_range_size`](#ldap_idmap_range_size)
* [`ldap_idmap_default_domain_sid`](#ldap_idmap_default_domain_sid)
* [`ldap_idmap_default_domain`](#ldap_idmap_default_domain)
* [`ldap_idmap_autorid_compat`](#ldap_idmap_autorid_compat)

##### <a name="name"></a>`name`

The name of the associated domain section in the configuration file

##### <a name="strip_128_bit_ciphers"></a>`strip_128_bit_ciphers`

Data type: `Boolean`

**DEPRECATED** - EL6-only - Will be removed in a future release

Default value: ``true``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Sssd::DebugLevel]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Boolean`



Default value: ``false``

##### <a name="ldap_uri"></a>`ldap_uri`

Data type: `Array[Simplib::URI,1]`



Default value: `simplib::lookup('simp_options::ldap::uri', { 'default_value' => undef })`

##### <a name="ldap_backup_uri"></a>`ldap_backup_uri`

Data type: `Optional[Array[Simplib::URI,1]]`



Default value: ``undef``

##### <a name="ldap_chpass_uri"></a>`ldap_chpass_uri`

Data type: `Optional[Array[Simplib::URI,1]]`



Default value: ``undef``

##### <a name="ldap_chpass_backup_uri"></a>`ldap_chpass_backup_uri`

Data type: `Optional[Array[Simplib::URI,1]]`



Default value: ``undef``

##### <a name="ldap_chpass_update_last_change"></a>`ldap_chpass_update_last_change`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_search_base"></a>`ldap_search_base`

Data type: `String[1]`



Default value: `simplib::lookup('simp_options::ldap::base_dn', { 'default_value' => undef })`

##### <a name="ldap_schema"></a>`ldap_schema`

Data type: `Sssd::LdapSchema`



Default value: `'rfc2307'`

##### <a name="ldap_default_bind_dn"></a>`ldap_default_bind_dn`

Data type: `String[1]`



Default value: `simplib::lookup('simp_options::ldap::bind_dn', { 'default_value' => undef })`

##### <a name="ldap_default_authtok_type"></a>`ldap_default_authtok_type`

Data type: `Optional[Sssd::LdapDefaultAuthtok]`



Default value: ``undef``

##### <a name="ldap_default_authtok"></a>`ldap_default_authtok`

Data type: `Optional[String[1]]`



Default value: `simplib::lookup('simp_options::ldap::bind_pw', { 'default_value' => undef })`

##### <a name="ldap_user_object_class"></a>`ldap_user_object_class`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_name"></a>`ldap_user_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_uid_number"></a>`ldap_user_uid_number`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_gid_number"></a>`ldap_user_gid_number`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_gecos"></a>`ldap_user_gecos`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_home_directory"></a>`ldap_user_home_directory`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_shell"></a>`ldap_user_shell`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_uuid"></a>`ldap_user_uuid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_objectsid"></a>`ldap_user_objectsid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_modify_timestamp"></a>`ldap_user_modify_timestamp`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_shadow_last_change"></a>`ldap_user_shadow_last_change`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_shadow_min"></a>`ldap_user_shadow_min`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_shadow_max"></a>`ldap_user_shadow_max`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_shadow_warning"></a>`ldap_user_shadow_warning`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_shadow_inactive"></a>`ldap_user_shadow_inactive`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_shadow_expire"></a>`ldap_user_shadow_expire`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_krb_last_pwd_change"></a>`ldap_user_krb_last_pwd_change`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_krb_password_expiration"></a>`ldap_user_krb_password_expiration`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_ad_account_expires"></a>`ldap_user_ad_account_expires`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_ad_user_account_control"></a>`ldap_user_ad_user_account_control`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_ns_account_lock"></a>`ldap_ns_account_lock`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_nds_login_disabled"></a>`ldap_user_nds_login_disabled`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_nds_login_expiration_time"></a>`ldap_user_nds_login_expiration_time`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_nds_login_allowed_time_map"></a>`ldap_user_nds_login_allowed_time_map`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_principal"></a>`ldap_user_principal`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_extra_attrs"></a>`ldap_user_extra_attrs`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="ldap_user_ssh_public_key"></a>`ldap_user_ssh_public_key`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_force_upper_case_realm"></a>`ldap_force_upper_case_realm`

Data type: `Boolean`



Default value: ``false``

##### <a name="ldap_enumeration_refresh_timeout"></a>`ldap_enumeration_refresh_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_purge_cache_timeout"></a>`ldap_purge_cache_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_user_fullname"></a>`ldap_user_fullname`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_member_of"></a>`ldap_user_member_of`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_authorized_service"></a>`ldap_user_authorized_service`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_authorized_host"></a>`ldap_user_authorized_host`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_group_object_class"></a>`ldap_group_object_class`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_group_name"></a>`ldap_group_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_group_gid_number"></a>`ldap_group_gid_number`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_group_member"></a>`ldap_group_member`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_group_uuid"></a>`ldap_group_uuid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_group_objectsid"></a>`ldap_group_objectsid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_group_modify_timestamp"></a>`ldap_group_modify_timestamp`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_group_type"></a>`ldap_group_type`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="ldap_group_nesting_level"></a>`ldap_group_nesting_level`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="ldap_groups_use_matching_rule_in_chain"></a>`ldap_groups_use_matching_rule_in_chain`

Data type: `Boolean`



Default value: ``false``

##### <a name="ldap_initgroups_use_matching_rule_in_chain"></a>`ldap_initgroups_use_matching_rule_in_chain`

Data type: `Boolean`



Default value: ``false``

##### <a name="ldap_use_tokengroups"></a>`ldap_use_tokengroups`

Data type: `Boolean`



Default value: ``false``

##### <a name="ldap_netgroup_object_class"></a>`ldap_netgroup_object_class`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_netgroup_name"></a>`ldap_netgroup_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_netgroup_member"></a>`ldap_netgroup_member`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_netgroup_triple"></a>`ldap_netgroup_triple`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_netgroup_uuid"></a>`ldap_netgroup_uuid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_netgroup_modify_timestamp"></a>`ldap_netgroup_modify_timestamp`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_service_name"></a>`ldap_service_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_service_port"></a>`ldap_service_port`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_service_proto"></a>`ldap_service_proto`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_service_search_base"></a>`ldap_service_search_base`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_search_timeout"></a>`ldap_search_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_enumeration_search_timeout"></a>`ldap_enumeration_search_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_network_timeout"></a>`ldap_network_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_opt_timeout"></a>`ldap_opt_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_connection_expire_timeout"></a>`ldap_connection_expire_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_page_size"></a>`ldap_page_size`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_disable_paging"></a>`ldap_disable_paging`

Data type: `Boolean`



Default value: ``false``

##### <a name="ldap_disable_range_retrieval"></a>`ldap_disable_range_retrieval`

Data type: `Boolean`



Default value: ``false``

##### <a name="ldap_sasl_minssf"></a>`ldap_sasl_minssf`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="ldap_deref_threshold"></a>`ldap_deref_threshold`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_tls_reqcert"></a>`ldap_tls_reqcert`

Data type: `Sssd::LdapTlsReqcert`



Default value: `'demand'`

##### <a name="ldap_tls_cacert"></a>`ldap_tls_cacert`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="app_pki_ca_dir"></a>`app_pki_ca_dir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="app_pki_key"></a>`app_pki_key`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="app_pki_cert"></a>`app_pki_cert`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="strip_128_bit_ciphers"></a>`strip_128_bit_ciphers`



Default value: ``true``

##### <a name="ldap_tls_cipher_suite"></a>`ldap_tls_cipher_suite`

Data type: `Array[String[1]]`



Default value: `['HIGH','-SSLv2']`

##### <a name="ldap_id_use_start_tls"></a>`ldap_id_use_start_tls`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_id_mapping"></a>`ldap_id_mapping`

Data type: `Boolean`



Default value: ``false``

##### <a name="ldap_min_id"></a>`ldap_min_id`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_max_id"></a>`ldap_max_id`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_sasl_mech"></a>`ldap_sasl_mech`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sasl_authid"></a>`ldap_sasl_authid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sasl_realm"></a>`ldap_sasl_realm`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sasl_canonicalize"></a>`ldap_sasl_canonicalize`

Data type: `Boolean`



Default value: ``false``

##### <a name="ldap_krb5_keytab"></a>`ldap_krb5_keytab`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ldap_krb5_init_creds"></a>`ldap_krb5_init_creds`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_krb5_ticket_lifetime"></a>`ldap_krb5_ticket_lifetime`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="krb5_server"></a>`krb5_server`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="krb5_backup_server"></a>`krb5_backup_server`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="krb5_realm"></a>`krb5_realm`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="krb5_canonicalize"></a>`krb5_canonicalize`

Data type: `Boolean`



Default value: ``false``

##### <a name="krb5_use_kdcinfo"></a>`krb5_use_kdcinfo`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_pwd_policy"></a>`ldap_pwd_policy`

Data type: `Enum['none','shadow','mit_kerberos']`



Default value: `(`

##### <a name="ldap_referrals"></a>`ldap_referrals`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_dns_service_name"></a>`ldap_dns_service_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_chpass_dns_service_name"></a>`ldap_chpass_dns_service_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_access_filter"></a>`ldap_access_filter`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_account_expire_policy"></a>`ldap_account_expire_policy`

Data type: `Sssd::LdapAccountExpirePol`

Set this to '' when you want to omit this configuration
in order to use the system default.

Default value: `'shadow'`

##### <a name="ldap_access_order"></a>`ldap_access_order`

Data type: `Sssd::LdapAccessOrder`



Default value: `['expire','lockout','ppolicy','pwd_expire_policy_renew']`

##### <a name="ldap_pwdlockout_dn"></a>`ldap_pwdlockout_dn`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_deref"></a>`ldap_deref`

Data type: `Optional[Sssd::LdapDeref]`



Default value: ``undef``

##### <a name="ldap_sudorule_object_class"></a>`ldap_sudorule_object_class`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudorule_name"></a>`ldap_sudorule_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudorule_command"></a>`ldap_sudorule_command`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudorule_host"></a>`ldap_sudorule_host`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudorule_user"></a>`ldap_sudorule_user`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudorule_option"></a>`ldap_sudorule_option`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudorule_runasuser"></a>`ldap_sudorule_runasuser`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudorule_runasgroup"></a>`ldap_sudorule_runasgroup`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudorule_notbefore"></a>`ldap_sudorule_notbefore`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudorule_notafter"></a>`ldap_sudorule_notafter`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudorule_order"></a>`ldap_sudorule_order`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudo_full_refresh_interval"></a>`ldap_sudo_full_refresh_interval`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_sudo_smart_refresh_interval"></a>`ldap_sudo_smart_refresh_interval`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_sudo_use_host_filter"></a>`ldap_sudo_use_host_filter`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_sudo_hostnames"></a>`ldap_sudo_hostnames`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="ldap_sudo_ip"></a>`ldap_sudo_ip`

Data type: `Optional[Array[String[1],1]]`



Default value: ``undef``

##### <a name="ldap_sudo_include_netgroups"></a>`ldap_sudo_include_netgroups`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_sudo_include_regexp"></a>`ldap_sudo_include_regexp`

Data type: `Boolean`



Default value: ``true``

##### <a name="ldap_autofs_map_master_name"></a>`ldap_autofs_map_master_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_autofs_map_object_class"></a>`ldap_autofs_map_object_class`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_autofs_map_name"></a>`ldap_autofs_map_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_autofs_entry_object_class"></a>`ldap_autofs_entry_object_class`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_autofs_entry_key"></a>`ldap_autofs_entry_key`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_autofs_entry_value"></a>`ldap_autofs_entry_value`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_netgroup_search_base"></a>`ldap_netgroup_search_base`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_user_search_base"></a>`ldap_user_search_base`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_group_search_base"></a>`ldap_group_search_base`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_sudo_search_base"></a>`ldap_sudo_search_base`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_autofs_search_base"></a>`ldap_autofs_search_base`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_idmap_range_min"></a>`ldap_idmap_range_min`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_idmap_range_max"></a>`ldap_idmap_range_max`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_idmap_range_size"></a>`ldap_idmap_range_size`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_idmap_default_domain_sid"></a>`ldap_idmap_default_domain_sid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_idmap_default_domain"></a>`ldap_idmap_default_domain`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_idmap_autorid_compat"></a>`ldap_idmap_autorid_compat`

Data type: `Boolean`



Default value: ``false``

## Functions

### <a name="sssdsupported_version"></a>`sssd::supported_version`

Type: Puppet Language

Returns ``true`` if the version of SSSD installed on the system is supported
and ``false`` otherwise.

Assumes that the system is relatively modern and therefore, supported by default

#### `sssd::supported_version()`

Returns ``true`` if the version of SSSD installed on the system is supported
and ``false`` otherwise.

Assumes that the system is relatively modern and therefore, supported by default

Returns: `Boolean`

## Data types

### <a name="sssdaddefaultright"></a>`Sssd::ADDefaultRight`

List of valid types for AD Provider setting ad_gpo_default_right

Alias of

```puppet
Enum['interactive', 'remote_interactive', 'network', 'batch', 'service', 'permit', 'deny']
```

### <a name="sssdaccessprovider"></a>`Sssd::AccessProvider`

List of valid  SSSD domain access providers

Alias of

```puppet
Enum['permit', 'deny', 'ldap', 'ipa', 'ad', 'simple']
```

### <a name="sssdauthprovider"></a>`Sssd::AuthProvider`

List of valid types for sssd domain authentication provider

Alias of

```puppet
Enum['ldap', 'krb5', 'ipa', 'ad', 'proxy', 'files', 'none']
```

### <a name="sssdchpassprovider"></a>`Sssd::ChpassProvider`

List of valid types for sssd domain change password provider

Alias of

```puppet
Enum['ldap', 'krb5', 'ipa', 'ad', 'proxy', 'none']
```

### <a name="sssddebuglevel"></a>`Sssd::DebugLevel`

Integer[0-9] or 2 byte Hexidecimal (ex. 0x0201)

Alias of

```puppet
Variant[Integer[0,9], Pattern[/0x\h{4}$/]]
```

### <a name="sssdidprovider"></a>`Sssd::IdProvider`

List of valid type for sssd domain ID provider.

Alias of

```puppet
Enum['proxy', 'ldap', 'ipa', 'ad', 'files']
```

### <a name="sssdldapaccessorder"></a>`Sssd::LdapAccessOrder`

List of valid values for ldap provider ldap_access_order setting

Alias of

```puppet
Array[Enum[
  'filter',
  'lockout',
  'ppolicy', # Only available in sssd >= 1.14.0
  'expire',
  'pwd_expire_policy_reject', # Only available in sssd >= 1.14.0
  'pwd_expire_policy_warn', # Only available in sssd >= 1.14.0
  'pwd_expire_policy_renew', # Only available in sssd >= 1.14.0
  'authorized_service',
  'host'
]]
```

### <a name="sssdldapaccountexpirepol"></a>`Sssd::LdapAccountExpirePol`

List of valid values for ldap provider ldap_account_expire_policy
'' corresponds to the default value (empty) per sssd-ldap(5) man page

Alias of

```puppet
Enum['', 'shadow', 'ad', 'rhds', 'ipa', '389ds', 'nds']
```

### <a name="sssdldapdefaultauthtok"></a>`Sssd::LdapDefaultAuthtok`

List of valid values for ldap provider default auth token

Alias of

```puppet
Enum['password', 'obfuscated_password']
```

### <a name="sssdldapderef"></a>`Sssd::LdapDeref`

List of valid values for ldap provider deref setting

Alias of

```puppet
Enum['never', 'searching', 'finding', 'always']
```

### <a name="sssdldapschema"></a>`Sssd::LdapSchema`

List of valid setting for ldap provider ldap_schema setting.

Alias of

```puppet
Enum['rfc2307', 'rfc2307bis', 'IPA', 'AD']
```

### <a name="sssdldaptlsreqcert"></a>`Sssd::LdapTlsReqcert`

List of valid setting for ldap provider ldap_tls_reqcert.

Alias of

```puppet
Enum['never', 'allow', 'try', 'demand', 'hard']
```

### <a name="sssdservices"></a>`Sssd::Services`

List of available sssd services

Alias of

```puppet
Array[Enum['nss','pam','sudo','autofs','ssh','pac','ifp']]
```

